module DataMapper
  module Types
    class Boolean < Type
      primitive TrueClass
    end # class Boolean
  end # module Types
end # module DataMapper
